@@ -7,8 +7,7 @@ extern double rho0;
 
 double xc_crit(int ctyp, double k, double L0, double hs, double m0, int N);
 
-void xcusum_crit
-( int *ctyp, double *k, double *L0, double *hs, double *mu0, int *r, double *h)
+void xcusum_crit(int *ctyp, double *k, double *L0, double *hs, double *mu0, int *r, double *h)
 {
   *h = xc_crit(*ctyp,*k,*L0,*hs,*mu0,*r);
 }
